@@ -1,10 +1,7 @@
 # frozen_string_literal: true
 
 require_relative '../command'
-require_relative '../../semver_dialects.rb'
-require_relative '../semantic_version/version_translator.rb'
-require_relative '../semantic_version/version_parser.rb'
-require_relative '../semantic_version/version_range.rb'
+require_relative '../../semver_dialects'
 
 module SemverDialects
   module Commands
@@ -22,7 +19,7 @@ module SemverDialects
         typ = @type.downcase
         raise SemverDialects::Error, 'wrong package type' unless @avail_types.include?(typ)
 
-        if VersionChecker.version_sat?(typ, @version, @constraint)
+        if SemverDialects.version_satisfies?(typ, @version, @constraint)
           output.puts "#{@version} matches #{@constraint} for #{@type}"
           0
         else
